import store from "@/store";
const { dispatch } = store;
import { Timing } from "@/components/index.js";
import moment from "moment";

export default {
  components: { Timing },
  props: ["dataSource"],
  data() {
    return {
      abbrDisabled: false,

      visible: false,
      submitLoading: false,
      saveCompanyRule: {
        name: [
          {
            required: true,
            message: "请输入企业名称",
            trigger: "blur"
          }
        ],
        abbr: [
          {
            required: true,
            message: "请输入企业简称",
            trigger: "blur"
          }
        ],
        contactName: [
          {
            required: true,
            message: "请输入联系人",
            trigger: "blur"
          }
        ],
        contactPhone: [
          {
            required: true,
            message: "请输入联系电话",
            trigger: "blur"
          }
        ],
        // expiredDate: [
        //   {
        //     type: "date",
        //     required: true,
        //     message: "请输入有效期",
        //     trigger: "blur"
        //   }
        // ],
      },
      companyForm: {
        id: 0,
        name: "",
        abbr: "",
        address: "",
        contactName: "",
        contactPhone: "",
        expiredDate: ""
      }
    };
  },
  computed: {

  },
  watch: {
    visible(show) {
      this.submitLoading = false;
      if (show) {
        this.$refs.companyForm.resetFields();

        if(this.dataSource) { // 编辑
          this.companyForm.id = this.dataSource.id;
          this.companyForm.name = this.dataSource.name;
          this.companyForm.abbr = this.dataSource.abbr;
          this.companyForm.address = this.dataSource.address;
          this.companyForm.contactName = this.dataSource.contactName;
          this.companyForm.contactPhone = this.dataSource.contactPhone;

          this.abbrDisabled = true;
        } else { // 添加
          this.abbrDisabled = false;
        }
      } else {

      }
    },
  },
  methods: {
    saveCompany() {
      this.$refs.companyForm.validate(valid => {
        if (valid) {
          this.submitLoading = true;
          const requestData = {
            id: this.companyForm.id,
            name: this.companyForm.name,
            abbr: this.companyForm.abbr,
            address: this.companyForm.address,
            contactName: this.companyForm.contactName,
            contactPhone: this.companyForm.contactPhone,
            expiredDate: moment(this.companyForm.expiredDate).valueOf()
          }
          var methodName = this.dataSource ? "invoke/asyncUpdateCompany" : "invoke/asyncCreateCompany";
          
          dispatch(methodName, requestData).then(({ code }) => {
            this.submitLoading = false;
            if (code === 1) {
              this.$Message.success(this.dataSource ? "修改成功" : "添加成功");
              this.$emit("search");
              this.visible = false;
            }
          });
        }
      });
    }
  },
  mounted() {
  }
};
